@@ -3,12 +3,17 @@ from ._countrydata import CountryData
 _countrydata = None
 
 
-def guess_country(country, attribute=None, default=None):
+def guess_country(country, attribute=None, default=None, regex_map=None):
+    """
+    Use built-in country data to identify `country`
+
+    See :meth:`.CountryData.get` for more information.
+    """
     global _countrydata
     if _countrydata is None:
         _countrydata = CountryData()
 
-    info = _countrydata.get(country)
+    info = _countrydata.get(country, regex_map=regex_map)
     if info:
         if attribute:
             try:
